@@ -693,6 +693,7 @@ begin_location_change (NautilusWindowSlot *slot,
 	gboolean force_reload;
         char *current_pos;
 	GFile *from_folder, *parent;
+	GList *parent_selection = NULL;
 
 	g_assert (slot != NULL);
         g_assert (location != NULL);
@@ -712,11 +713,14 @@ begin_location_change (NautilusWindowSlot *slot,
 			from_folder = parent;
 			parent = g_file_get_parent (from_folder);
 		}
+
 		if (parent != NULL) {
-			new_selection = g_list_prepend (NULL, nautilus_file_get (from_folder));
+			new_selection = parent_selection = 
+				g_list_prepend (NULL, nautilus_file_get (from_folder));
+			g_object_unref (parent);
 		}
+
 		g_object_unref (from_folder);
-		g_object_unref (parent);
 	}
 
 	end_location_change (slot);
@@ -761,6 +765,10 @@ begin_location_change (NautilusWindowSlot *slot,
 
         nautilus_directory_unref (directory);
 
+	if (parent_selection != NULL) {
+		g_list_free_full (parent_selection, g_object_unref);
+	}
+
         /* Set current_bookmark scroll pos */
         if (slot->current_location_bookmark != NULL &&
             slot->content_view != NULL) {
@@ -889,10 +897,12 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		}
 
 		g_clear_object (&slot->pending_location);
+		g_free (slot->pending_scroll_to);
 	
 		slot->pending_location = nautilus_file_get_parent_location (file);
 		slot->pending_selection = g_list_prepend (NULL, nautilus_file_ref (file));
 		slot->determine_view_file = nautilus_file_get_parent (file);
+		slot->pending_scroll_to = nautilus_file_get_uri (file);
 
 		nautilus_file_invalidate_all_attributes (slot->determine_view_file);
 		nautilus_file_call_when_ready (slot->determine_view_file,
@@ -1227,6 +1237,8 @@ real_setup_loading_floating_bar (NautilusWindowSlot *slot)
 	nautilus_floating_bar_add_action (NAUTILUS_FLOATING_BAR (slot->floating_bar),
 					  GTK_STOCK_STOP,
 					  NAUTILUS_FLOATING_BAR_ACTION_ID_STOP);
+
+	gtk_widget_set_halign (slot->floating_bar, GTK_ALIGN_END);
 	gtk_widget_show (slot->floating_bar);
 }
 
